/****************************************************************************
** Meta object code from reading C++ file 'coord_model.h'
**
** Created: Sat Feb 6 15:10:00 2010
**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../qt/coord_model.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'coord_model.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 61
#error "This file was generated using the moc from 4.5.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_CoordModel[] = {

 // content:
       2,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   12, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors

 // signals: signature, parameters, type, tag, flags
      22,   12,   11,   11, 0x05,

       0        // eod
};

static const char qt_meta_stringdata_CoordModel[] = {
    "CoordModel\0\0iNewCoord\0coordChanged(Coord)\0"
};

const QMetaObject CoordModel::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_CoordModel,
      qt_meta_data_CoordModel, 0 }
};

const QMetaObject *CoordModel::metaObject() const
{
    return &staticMetaObject;
}

void *CoordModel::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_CoordModel))
        return static_cast<void*>(const_cast< CoordModel*>(this));
    return QObject::qt_metacast(_clname);
}

int CoordModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: coordChanged((*reinterpret_cast< const Coord(*)>(_a[1]))); break;
        default: ;
        }
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void CoordModel::coordChanged(const Coord & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_END_MOC_NAMESPACE
